@@ -49,8 +49,3 @@ class Config(Resource):
 
 	def _set_path(self, path):
 		self._path = PosixPath(path).resolve()
-
-	def is_copy_default(self):
-		consts = self.__class__.__dict__.get('__annotations__')
-
-		return self.default_action == consts['ACTION_COPY']
